@@ -217,7 +217,7 @@ impl PlotElement
 		}
 	}
 
-	fn write_args(&self, writer: &mut Writer)
+	fn write_args(&self, writer: &mut Writer, version: GnuplotVersion)
 	{
 		let options = &self.options;
 		match self.source_type
@@ -356,7 +356,7 @@ impl PlotElement
 
 		if self.plot_type.is_line()
 		{
-			AxesCommonData::write_line_options(writer, options);
+			AxesCommonData::write_line_options(writer, options, version);
 		}
 
 		if self.plot_type.is_points()
@@ -510,7 +510,7 @@ pub fn write_out_label_options(label_type: LabelType, options: &[LabelOption<Str
 	}
 }
 
-#[derive(Copy, Clone)]
+#[derive(Copy, Clone, PartialEq)]
 pub enum TickAxis
 {
 	XTickAxis,
@@ -543,6 +543,17 @@ impl TickAxis
 		}
 	}
 
+	pub fn to_mtick_str(&self) -> &str
+	{
+		match *self
+		{
+			XTickAxis => "mxtics",
+			YTickAxis => "mytics",
+			ZTickAxis => "mztics",
+			CBTickAxis => "mcbtics",
+		}
+	}
+
 	pub fn to_range_str(&self) -> &str
 	{
 		match *self
@@ -619,7 +630,10 @@ pub struct AxisData
 	pub max: AutoOption<f64>,
 	pub reverse: bool,
 	pub grid: bool,
+	pub mgrid: bool,
 	pub is_time: bool,
+	pub show: bool,
+	pub options: Vec<PlotOption<String>>,
 }
 
 impl AxisData
@@ -636,12 +650,36 @@ impl AxisData
 			max: Auto,
 			reverse: false,
 			grid: false,
+			mgrid: false,
 			is_time: false,
+			show: false,
+			options: vec![],
 		}
 	}
 
-	pub fn write_out_commands(&self, w: &mut Writer)
+	pub fn write_out_commands(&self, w: &mut Writer, version: GnuplotVersion)
 	{
+		if self.axis != TickAxis::CBTickAxis
+		{
+			if self.show
+			{
+				w.write_str("set ");
+				w.write_str(self.axis.to_axis_str());
+				w.write_str("zeroaxis ");
+
+				AxesCommonData::write_color_options(w, &self.options, Some("black"));
+				AxesCommonData::write_line_options(w, &self.options, version);
+			}
+			else
+			{
+				w.write_str("unset ");
+				w.write_str(self.axis.to_axis_str());
+				w.write_str("zeroaxis ");
+			}
+		}
+
+		w.write_str("\n");
+
 		let log = match self.log_base
 		{
 			Some(base) =>
@@ -909,6 +947,11 @@ impl AxisData
 		self.grid = show;
 	}
 
+	pub fn set_minor_grid(&mut self, show: bool)
+	{
+		self.mgrid = show;
+	}
+
 	pub fn set_time(&mut self, is_time: bool)
 	{
 		self.is_time = is_time;
@@ -948,6 +991,7 @@ pub struct AxesCommonData
 {
 	pub commands: Vec<u8>,
 	pub grid_options: Vec<PlotOption<String>>,
+	pub minor_grid_options: Vec<PlotOption<String>>,
 	pub grid_front: bool,
 	pub elems: Vec<PlotElement>,
 	pub grid_rows: u32,
@@ -965,6 +1009,7 @@ impl AxesCommonData
 		AxesCommonData {
 			commands: vec![],
 			grid_options: vec![],
+			minor_grid_options: vec![],
 			grid_front: false,
 			elems: Vec::new(),
 			grid_rows: 0,
@@ -976,7 +1021,7 @@ impl AxesCommonData
 		}
 	}
 
-	pub fn write_grid_options(&self, c: &mut Writer, axes: &[TickAxis])
+	pub fn write_grid_options(&self, c: &mut Writer, axes: &[TickAxis], version: GnuplotVersion)
 	{
 		if !axes.is_empty()
 		{
@@ -985,6 +1030,11 @@ impl AxesCommonData
 			{
 				c.write_str(axis.to_tick_str());
 				c.write_str(" ");
+				if self.x_axis.axis == *axis && self.x_axis.mgrid
+					|| self.y_axis.axis == *axis && self.y_axis.mgrid {
+					c.write_str(axis.to_mtick_str());
+					c.write_str(" ");
+				}
 			}
 
 			if self.grid_front
@@ -996,13 +1046,16 @@ impl AxesCommonData
 				c.write_str("back ");
 			}
 
-			AxesCommonData::write_line_options(c, &self.grid_options);
+			AxesCommonData::write_line_options(c, &self.grid_options, version);
 			AxesCommonData::write_color_options(c, &self.grid_options, None);
+			c.write_str(", ");
+			AxesCommonData::write_line_options(c, &self.minor_grid_options, version);
+			AxesCommonData::write_color_options(c, &self.minor_grid_options, None);
 			c.write_str("\n");
 		}
 	}
 
-	pub fn write_line_options(c: &mut Writer, options: &[PlotOption<String>])
+	pub fn write_line_options(c: &mut Writer, options: &[PlotOption<String>], version: GnuplotVersion)
 	{
 		let mut found = false;
 		c.write_str(" lw ");
@@ -1018,18 +1071,23 @@ impl AxesCommonData
 			c.write_str("1");
 		}
 
-		c.write_str(" lt ");
-		let mut found = false;
-		first_opt!{options,
-			LineStyle(d) =>
-			{
-				write!(c, "{}", d.to_int());
-				found = true;
+		if version.major >= 5
+		{
+			first_opt!{options,
+				LineStyle(d) =>
+				{
+					write!(c, " dt {}", d.to_int());
+				}
 			}
 		}
-		if !found
+		else
 		{
-			c.write_str("1");
+			first_opt!{options,
+				LineStyle(d) =>
+				{
+					write!(c, " lt {}", d.to_int());
+				}
+			}
 		}
 	}
 
@@ -1052,15 +1110,15 @@ impl AxesCommonData
 		}
 	}
 
-	pub fn write_out_commands(&self, writer: &mut Writer)
+	pub fn write_out_commands(&self, writer: &mut Writer, version: GnuplotVersion)
 	{
 		writer.write_all(&self.commands[..]);
-		self.x_axis.write_out_commands(writer);
-		self.y_axis.write_out_commands(writer);
-		self.cb_axis.write_out_commands(writer);
+		self.x_axis.write_out_commands(writer, version);
+		self.y_axis.write_out_commands(writer, version);
+		self.cb_axis.write_out_commands(writer, version);
 	}
 
-	pub fn write_out_elements(&self, cmd: &str, writer: &mut Writer)
+	pub fn write_out_elements(&self, cmd: &str, writer: &mut Writer, version: GnuplotVersion)
 	{
 		write!(writer, "{}", cmd);
 
@@ -1071,7 +1129,7 @@ impl AxesCommonData
 			{
 				write!(writer, ",");
 			}
-			e.write_args(writer);
+			e.write_args(writer, version);
 			first = false;
 		}
 
@@ -1435,6 +1493,16 @@ pub trait AxesCommon: AxesCommonPrivate
 		self
 	}
 
+	/// Shows the minor grid on the X axis.
+	///
+	/// # Arguments
+	/// * `show` - Whether to show the grid.
+	fn set_x_minor_grid<'l>(&'l mut self, show: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().x_axis.set_minor_grid(show);
+		self
+	}
+
 	/// Shows the grid on the Y axis.
 	///
 	/// # Arguments
@@ -1445,6 +1513,16 @@ pub trait AxesCommon: AxesCommonPrivate
 		self
 	}
 
+	/// Shows the minor grid on the Y axis.
+	///
+	/// # Arguments
+	/// * `show` - Whether to show the grid.
+	fn set_y_minor_grid<'l>(&'l mut self, show: bool) -> &'l mut Self
+	{
+		self.get_common_data_mut().y_axis.set_minor_grid(show);
+		self
+	}
+
 	/// Shows the grid on the color bar axis.
 	///
 	/// # Arguments
@@ -1470,6 +1548,19 @@ pub trait AxesCommon: AxesCommonPrivate
 		self
 	}
 
+	/// Set the minor grid options.
+	///
+	/// # Arguments
+	/// * `options` - Styling options of the grid. Relevant options are:
+	///      * `Color` - Specifies the color of the grid lines
+	///      * `LineStyle` - Specifies the style of the grid lines
+	///      * `LineWidth` - Specifies the width of the grid lines
+	fn set_minor_grid_options<'l>(&'l mut self, options: &[PlotOption<&str>]) -> &'l mut Self
+	{
+		self.get_common_data_mut().minor_grid_options = options.to_one_way_owned();
+		self
+	}
+
 	/// Sets the X axis be time.
 	///
 	/// If true, the axis is interpreted as seconds from the Unix epoch. Use the `Format` TickOption to
